/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.service;

import org.apache.lucene.queryParser.ParseException;

import java.util.List;

/**
 * The Interface ObjectListService.
 *
 * @param <T>
 *            the generic type
 * @param <ID>
 *            the generic type
 */
public interface ObjectQueryService<T, ID> extends ObjectLoadService<T, ID> {

    /**
     * Count.
     *
     * @return the count
     */
    int count();

    /**
     * Find all.
     *
     * @param startIndex
     *            the start index
     * @param fetchSize
     *            the fetch size
     * @return the list
     */
    List<T> findAll(final int startIndex, final int fetchSize);

    /**
     * Count query results.
     *
     * @param searchQuery
     *            the query
     * @return the count
     * @throws ParseException when the query cannot be parsed
     */
    int countByName(String searchQuery) throws ParseException;

    /**
     * Find records according to query.
     *
     * @param searchQuery
     *            the query
     * @param startIndex
     *            the start index
     * @param fetchSize
     *            the fetch size
     * @return the list
     * @throws ParseException when the query cannot be parsed
     */
    List<T> searchByName(final String searchQuery, final int startIndex,
            final int fetchSize) throws ParseException;
}
