/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.domain;

import org.junit.Assert;
import org.junit.Test;

import almira.sample.domain.Catapult;
import almira.sample.testing.CatapultBuilder;


public class CatapultObjectTest {

    private final Catapult x = new CatapultBuilder(1L, "cata1").build();
    private final Catapult y = new CatapultBuilder(2L, "cata2").build();

    @Test
    public void toStringContainsIdAndName() {
        String id = "" + x.getId();
        String name = x.getName();

        Assert.assertTrue("String contains id", x.toString().contains("id=" + id));
        Assert.assertTrue("String contains name", x.toString().contains("name=" + name));
    }

    @Test
    public void compareToIsSymetric() {
        Assert.assertTrue(x.compareTo(y) == -y.compareTo(x));
    }

    @Test
    public void compareToIsTransitive() {
        Catapult z = new CatapultBuilder(2L, "cata3").build();
        Assert.assertTrue(x.compareTo(y) < 0);
        Assert.assertTrue(y.compareTo(z) < 0);
        Assert.assertTrue(x.compareTo(z) < 0);
    }

    @Test
    public void comparteToSatisfiesContractWhenEquals() {
        Catapult z = new CatapultBuilder(2L, "cata1").build();
        Assert.assertTrue(x.compareTo(z) == 0);
        Assert.assertTrue(x.compareTo(y) == z.compareTo(y));
        Assert.assertTrue(x.equals(z));
    }
}
