/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.aspects;

import javax.validation.constraints.NotNull;
import java.util.logging.Logger;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.reflect.MethodSignature;

/**
 * Aspect to validate NotNull annotation.
 * http://aspectj.2085585.n4.nabble.com/Is-it-possible-to-define-a-scope-of-methods-accepting-at-least-one-non-primitive-argument-td4195341.html
 */
public aspect ValidationAspect {

    private static final Logger LOG = Logger.getLogger("ValidationAspect");

    pointcut nullArg0(Object o): execution(* *(@NotNull (*),..)) && args(o,..);
    pointcut nullArg1(Object o): execution(* *(*,@NotNull (*),..)) && args(*,o,..);
    pointcut nullArg2(Object o): execution(* *(*,*,@NotNull (*),..)) && args(*,*,o,..);
    pointcut nullArg3(Object o): execution(* *(*,*,*,@NotNull (*),..)) && args(*,*,*,o,..);
    pointcut nullArg4(Object o): execution(* *(*,*,*,*,@NotNull (*),..)) && args(*,*,*,*,o,..);
    pointcut nullArg5(Object o): execution(* *(*,*,*,*,*,@NotNull (*),..)) && args(*,*,*,*,*,o,..);

    before(Object o): nullArg0(o) { assertNotNull(o, 0, thisJoinPointStaticPart); }
    before(Object o): nullArg1(o) { assertNotNull(o, 1, thisJoinPointStaticPart); }
    before(Object o): nullArg2(o) { assertNotNull(o, 2, thisJoinPointStaticPart); }
    before(Object o): nullArg3(o) { assertNotNull(o, 3, thisJoinPointStaticPart); }
    before(Object o): nullArg4(o) { assertNotNull(o, 4, thisJoinPointStaticPart); }
    before(Object o): nullArg5(o) { assertNotNull(o, 5, thisJoinPointStaticPart); }

    protected void assertNotNull(Object o, int index, JoinPoint.StaticPart jp) {

        LOG.fine("" + jp + ", parameter" + index + "=" + o);

        if (o == null) {
            MethodSignature ms = (MethodSignature)jp.getSignature();
            throw new IllegalArgumentException("The '" + ms.getParameterNames()[index]
                + "' parameter of the method '" + ms + "' cannot be null (" + jp.getSourceLocation() + ").");
        }
    }
}
