/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.aspects;

import org.junit.Before;
import org.junit.Test;

/**
 * The Class Jsr303Test.
 */
public class Jsr303Test {

    private AdviceSubject subject = null;

    @Before
    public void setUp() {
        subject = new AdviceSubject();
    }

    // Static method
    @Test (expected=IllegalArgumentException.class)
    public void nullParameterOnStaticMethodThrowsException() {
        AdviceSubject.staticMethod(null);
    }

    // Basic test
    @Test
    public void noExceptionWithAnnotationAndValueNotNull() {
        subject.methodWithVisibilityPublic("some value");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterOnPublicMethodThrowsException() {
        subject.methodWithVisibilityPublic(null);
    }

    // Visibility
    @Test (expected=IllegalArgumentException.class)
    public void indirectCallToPrivateMethodWithNullParameterThrowsException() {
        subject.internalCallToAdvisedMethod(null);
    }

    @Test (expected=IllegalArgumentException.class)
    public void inheritedMethodWithNullParameterThrowsException() {
        AdviceSubject inherited = new AdviceSubject() {
            // empty
        };
        inherited.methodWithVisibilityProtected(null);
    }

    // Multiple parameters
    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos0ThrowsException() {
        subject.multiParamPos0(null, "v", "v", "v", "v", "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos1ThrowsException() {
        subject.multiParamPos1("v", null, "v", "v", "v", "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos2ThrowsException() {
        subject.multiParamPos2("v", "v", null, "v", "v", "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos3ThrowsException() {
        subject.multiParamPos3("v", "v", "v", null, "v", "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos4ThrowsException() {
        subject.multiParamPos4("v", "v", "v", "v", null, "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void nullParameterInPos5ThrowsException() {
        subject.multiParamPos5("v", "v", "v", "v", "v", null);
    }

    // Multiple annotations
    @Test (expected=IllegalArgumentException.class)
    public void multipleNullParametersPos0NullThrowsException() {
        subject.multiParamsAndAnnotations(null, "v", "v");
    }

    @Test (expected=IllegalArgumentException.class)
    public void multipleNullParametersPos3NullThrowsException() {
        subject.multiParamsAndAnnotations("v", "v", null);
    }

    @Test (expected=IllegalArgumentException.class)
    public void multipleNullParametersPos0and3NullThrowsException() {
        subject.multiParamsAndAnnotations(null, "v", null);
    }
}

