/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.client;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.util.List;

import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;

import almira.sample.domain.Catapult;
import almira.sample.service.ObjectQueryService;
import almira.sample.testing.CatapultBuilder;

import com.mycila.testing.junit.MycilaJunitRunner;
import com.mycila.testing.plugin.jmock.Mock;
import com.mycila.testing.plugin.jmock.MockContext;


@RunWith(MycilaJunitRunner.class)
public final class ListCatapultTest {

    @MockContext private Mockery context;
    @Mock private ObjectQueryService<Catapult, Long> queryService;

    private static final int MAX_RECORDS = 5;
    private static final String CATAPULT_NAME = "catapultName";
    private static final List<Catapult> RESULT_LIST = new CatapultBuilder(1L, CATAPULT_NAME).asList();

    @Test
    public void getFactoryBeanInstanceIsNotNull() {
        Assert.assertNotNull(ListCatapults.getFactoryBeanInstance("http://localhost:8080/catapult/services/list"));
    }

    @Test
    public void executesQueryWithoutErrors() {
        context.checking(new Expectations() {
            {
                oneOf(queryService).findAll(0, MAX_RECORDS);
                will(returnValue(RESULT_LIST));
            }
        });
        PrintStream sysOut = System.out;
        try {
            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            System.setOut(new PrintStream (baos));
            ListCatapults.executeQuery(queryService);
            Assert.assertTrue("Output contains Catapult name", baos.toString().contains(CATAPULT_NAME));
        }
        finally {
            System.setOut(sysOut);
        }
    }
}
