/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import java.io.Serializable;
import java.util.List;

import org.apache.lucene.queryParser.ParseException;

import almira.sample.domain.DomainObject;


/**
 * http://stackoverflow.com/questions/2387431/spring-autowiring-class-vs-interface
 *
 * @param <T>
 * @author 'Daniel TISCHER'
 */
public interface DaoHibernateSearch<T extends DomainObject<ID>, ID extends Serializable> extends Dao<T, ID> {

    /**
     * Search catapults by name.
     *
     * @param searchQuery the query
     * @param startIndex the start index
     * @param fetchSize the fetch size
     * @return the result list
     * @throws ParseException if the query cannot be parsed
     */
    List<T> searchByName(String searchQuery, final int startIndex, final int fetchSize) throws ParseException;

    void purgeIndex();

    void rebuildIndex() throws InterruptedException;

    void flushToIndexes();

    @Override
    long count();

    long countByName(String searchQuery) throws ParseException;
}
