/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import java.util.logging.Logger;

import org.infinispan.notifications.Listener;
import org.infinispan.notifications.cachelistener.annotation.CacheEntriesEvicted;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryCreated;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryModified;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryRemoved;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryVisited;
import org.infinispan.notifications.cachemanagerlistener.annotation.CacheStarted;
import org.infinispan.notifications.cachemanagerlistener.annotation.CacheStopped;
import org.infinispan.notifications.cachemanagerlistener.event.Event;

/**
 * The listener interface for receiving infinispanCache events.
 *
 * See https://docs.jboss.org/author/display/ISPN/Listeners+and+Notifications
 */
@Listener
public class InfinispanCacheListener {

    /** The LOG. */
    private static final Logger LOG = Logger
            .getLogger(InfinispanCacheListener.class.getName());

    /**
     * Cache started.
     *
     * @param event the event
     */
    @CacheStarted
    public void cacheStarted(Event event) {
        LOG.info("Cache started: " + event + "\n");
    }

    /**
     * Cache stopped.
     *
     * @param event the event
     */
    @CacheStopped
    public void cacheStopped(Event event) {
        LOG.info("Cache stopped: " + event + "\n");
    }

    /**
     * Handle.<br/>
     * See http://docs.jboss.org/infinispan/5.0/apidocs/org/infinispan/notifications/cachelistener/annotation/package-summary.html
     *
     * @param event the event
     */
    @CacheEntryCreated
    @CacheEntryModified
    @CacheEntryRemoved
    @CacheEntryVisited
    @CacheEntriesEvicted
    public void handle(
            org.infinispan.notifications.cachelistener.event.Event<?, ?> event) {
        LOG.info("Cache entry modified: " + event + "\n");
    }
}
