/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.service;

import java.util.List;

import javax.annotation.Resource;

import org.apache.lucene.queryParser.ParseException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import almira.sample.dao.DaoHibernateSearch;
import almira.sample.domain.Catapult;
import almira.sample.service.ObjectQueryService;


/**
 * A service interface to list Catapults.
 */
@Service("catapultQueryService")
public final class CatapultQueryService implements ObjectQueryService<Catapult, Long> {

    @Resource(name = "catapultDaoHibernateSearch")
    private DaoHibernateSearch<Catapult, Long> dao;

    public void setDao(DaoHibernateSearch<Catapult, Long> dao) {
        this.dao = dao;
    }

    @Override
    @Transactional(readOnly = true)
    public Catapult load(Long id) {
        return dao.findById(id, false);
    }

    @Override
    @Transactional(readOnly = true)
    public int count() {
        // TODO: remove (int) cast
        return (int) dao.count();
    }

    @Override
    @Transactional(readOnly = true)
    public List<Catapult> findAll(int startIndex, int fetchSize) {
        return dao.findAll(startIndex, fetchSize);
    }

    @Override
    @Transactional(readOnly = true)
    public List<Catapult> searchByName(final String searchQuery, final int startIndex, final int fetchSize) throws ParseException {
        return dao.searchByName(searchQuery, startIndex, fetchSize);
    }

    @Override
    @Transactional(readOnly = true)
    public int countByName(String searchQuery) throws ParseException {
        // TODO: remove (int) cast
        return (int) dao.countByName(searchQuery);
    }
}
