/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import static org.fest.assertions.Assertions.assertThat;

import org.infinispan.notifications.cachemanagerlistener.event.Event;
import org.infinispan.notifications.cachemanagerlistener.event.EventImpl;
import org.junit.Test;

import almira.sample.dao.InfinispanCacheListener;
import almira.sample.logging.TestingLogHandler;


public class InfinispanCacheListenerTest {

    // save log messages for testing
    private static final TestingLogHandler LOG = TestingLogHandler.register();

    // dummy test objects
    private static final InfinispanCacheListener LISTENER = new InfinispanCacheListener();
    private static final Event EVENT = new EventImpl();
    @SuppressWarnings("rawtypes")
    private static final org.infinispan.notifications.cachelistener.event.EventImpl TRANSACTIONAL_EVENT = new org.infinispan.notifications.cachelistener.event.EventImpl();

    @Test
    public void cacheStarted() {
        LISTENER.cacheStarted(EVENT);
        assertThat(LOG.getLastLogRecord()).as("Log").isEqualTo("Cache started: " + EVENT + "\n");
    }

    @Test
    public void cacheStopped() {
        LISTENER.cacheStopped(EVENT);
        assertThat(LOG.getLastLogRecord()).as("Log").isEqualTo("Cache stopped: " + EVENT + "\n");
    }

    @Test
    public void handle() {
        LISTENER.handle(TRANSACTIONAL_EVENT);
        assertThat(LOG.getLastLogRecord()).as("Log").isEqualTo("Cache entry modified: " + TRANSACTIONAL_EVENT + "\n");
    }
}
