/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import static org.fest.assertions.Assertions.assertThat;

import java.util.List;

import javax.annotation.Resource;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.test.context.transaction.TransactionConfiguration;
import org.springframework.transaction.annotation.Transactional;


import almira.sample.dao.AbstractSpringDbUnitTestCase;
import almira.sample.dao.Dao;
import almira.sample.dao.DataSet;
import almira.sample.dao.ExpectedDataSet;
import almira.sample.domain.Catapult;
import almira.sample.testing.CatapultBuilder;


@Transactional
@TransactionConfiguration(transactionManager="transactionManager", defaultRollback=false)
public class TSCCatapultDaoHibernate extends AbstractSpringDbUnitTestCase {

    private static final int RESULT_SIZE = 11;
    private static final String LOAD_CATAPULT_NAME = "loadCatapult1";

    @Resource(name = "catapultDaoHibernate")
    private Dao<Catapult, Long> dao;

    @Test
    @DataSet
    public void loadCatapult() {
        Catapult catapult = dao.findByName(LOAD_CATAPULT_NAME);
        assertThat(catapult).isNotNull();
        assertThat(catapult.getName()).isEqualTo(LOAD_CATAPULT_NAME);
    }

    @Test
    @DataSet("empty.xml")
    @ExpectedDataSet
    public void saveCatapult() {
        Catapult catapult = new Catapult();
        catapult.setName("saveCatapult");
        catapult = dao.makePersistent(catapult);

        dao.flush();

        assertThat(catapult.getId()).isNotNull();
        assertThat(catapult.getCreated()).isNotNull();

        addReplacementObject("[ID]", catapult.getId());
        addReplacementObject("[CREATION_DATE]", catapult.getCreated());
        addReplacementObject("[MODIFICATION_DATE]", catapult.getLastModified());
    }

    @Test
    @DataSet("TSCCatapultDaoHibernate.loadCatapult.xml")
    public void findAllFinds() {
        final List<Catapult> expectedList = new CatapultBuilder(1L, "loadCatapult1").asList();
        for (long i=2; i<=RESULT_SIZE; i++) {
            expectedList.add(new CatapultBuilder(i, "loadCatapult" + i).build());
        }
        List<Catapult> resultList = dao.findAll(0, RESULT_SIZE);
        Assert.assertEquals(expectedList, resultList);
    }

    @Test
    @DataSet("TSCCatapultDaoHibernate.loadCatapult.xml")
    public void countAllCounts() {
        Assert.assertEquals(RESULT_SIZE, dao.count());
    }
}
