/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import static org.fest.assertions.Assertions.assertThat;

import java.util.List;

import javax.annotation.Resource;

import org.apache.lucene.queryParser.ParseException;
import org.junit.Test;
import org.springframework.test.context.transaction.TransactionConfiguration;
import org.springframework.transaction.annotation.Transactional;


import almira.sample.dao.AbstractSpringDbUnitTestCase;
import almira.sample.dao.DaoHibernateSearch;
import almira.sample.dao.DataSet;
import almira.sample.domain.Catapult;


@Transactional
@TransactionConfiguration(transactionManager="transactionManager", defaultRollback=false)
public class TSCCatapultDaoHibernateSearch extends AbstractSpringDbUnitTestCase {

    private static final int SEARCH_RESULT_SIZE = 3;
    private static final String LOAD_CATAPULT_NAME = "loadCatapult1";
    private static final String SEARCH_CATAPULT_NAME = "searchCatapult1";

    @Resource(name = "catapultDaoHibernateSearch")
    private DaoHibernateSearch<Catapult, Long> dao;

    @Test
    @DataSet
    public void searchCatapultByName() throws ParseException, InterruptedException {
        // execute search
        List<Catapult> resultList = dao.searchByName(SEARCH_CATAPULT_NAME, 0, 1);

        // assert
        assertThat(resultList.size()).isGreaterThan(0);
        assertThat(resultList.get(0).getName()).isEqualTo(SEARCH_CATAPULT_NAME);
    }

    @Test
    @DataSet("TSCCatapultDaoHibernate.loadCatapult.xml")
    public void indexIsRebuiltProperly() throws InterruptedException, ParseException {

        dao.rebuildIndex();

        // execute search
        List<Catapult> resultList = dao.searchByName(LOAD_CATAPULT_NAME, 0, 1);

        // assert
        assertThat(resultList.size()).isGreaterThan(0);
        assertThat(resultList.get(0).getName()).isEqualTo(LOAD_CATAPULT_NAME);
    }

    @Test
    @DataSet("TSCCatapultDaoHibernate.loadCatapult.xml")
    public void countByNameCountsAll() throws ParseException {
        assertThat(dao.countByName("loadCatapult1*")).isEqualTo(SEARCH_RESULT_SIZE);
    }
}
