/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.dao;

import static org.fest.assertions.Assertions.assertThat;
import static org.junit.Assert.assertNotNull;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.junit.Test;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.transaction.annotation.Transactional;


import almira.sample.dao.AbstractSpringTransactionalTestCase;
import almira.sample.domain.Catapult;


public class TSCTransactionRollback extends AbstractSpringTransactionalTestCase {

    @PersistenceContext
    private EntityManager em;

    private static Long staticId;

    private static final String CATAPULT_NAME = "Tx-1";

    @Test
    @Transactional(readOnly = false)
    public void persistInTransaction() {
        Catapult catapult = new Catapult();
        catapult.setName(CATAPULT_NAME);
        em.persist(catapult);
        em.flush(); // send SQL to DB
        staticId = catapult.getId();
        assertNotNull("id should not be null after persist()", staticId);
    }

    @Test
    @Rollback(true)
    @Transactional(readOnly = false)
    public void updateNameRollback() {
        Catapult catapult = em.find(Catapult.class, staticId);
        catapult.setName("NewName");
        em.merge(catapult);
        em.flush(); // send SQL to DB
    }

    @AfterTransaction
    public void checkPostConditions() {
        Catapult c = em.find(Catapult.class, staticId);
        assertThat(c.getName()).isEqualTo(CATAPULT_NAME);
    }
}
