/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.service;

import static org.fest.assertions.Assertions.assertThat;

import java.util.List;

import org.apache.lucene.queryParser.ParseException;
import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import almira.sample.dao.DaoHibernateSearch;
import almira.sample.domain.Catapult;
import almira.sample.service.CatapultQueryService;
import almira.sample.testing.CatapultBuilder;

import com.mycila.testing.junit.MycilaJunitRunner;
import com.mycila.testing.plugin.jmock.Mock;
import com.mycila.testing.plugin.jmock.MockContext;


@RunWith(MycilaJunitRunner.class)
public class CatapultQueryServiceTest {

    private static final String CATAPULT_NAME = "test";
    private static final Catapult catapult = new CatapultBuilder(1L, CATAPULT_NAME).build();
    private static final List<Catapult> catapultList = new CatapultBuilder(1L, CATAPULT_NAME).asList();

    @MockContext private Mockery context;
    @Mock private DaoHibernateSearch<Catapult, Long> dao;
    private CatapultQueryService service;

    @Before
    public void setUp() {
        service = new CatapultQueryService();
        service.setDao(dao);
    }

    @Test
    public void load() throws InterruptedException {
        context.checking(new Expectations() {{ oneOf(dao).findById(1L, false); will(returnValue(catapult)); }} );
        service.load(1L);
    }

    @Test
    public void count() {
        context.checking(new Expectations() {{ oneOf(dao).count(); will(returnValue(1L)); }} );
        assertThat(service.count()).isEqualTo(1);
    }

    @Test
    public void findAll() {
        context.checking(new Expectations() {{ oneOf(dao).findAll(0, 1); will(returnValue(catapultList)); }} );
        List<Catapult> resultList = service.findAll(0, 1);
        assertThat(resultList).isEqualTo(catapultList);
    }

    @Test
    public void searchByName() throws ParseException {
        context.checking(new Expectations() {{ oneOf(dao).searchByName(CATAPULT_NAME, 0, 1); will(returnValue(catapultList)); }} );
        List<Catapult> resultList = service.searchByName(CATAPULT_NAME, 0, 1);
        assertThat(resultList).isEqualTo(catapultList);
    }

    @Test
    public void countByName() throws ParseException {
        context.checking(new Expectations() {{ oneOf(dao).countByName(CATAPULT_NAME); will(returnValue(1L)); }} );
        assertThat(service.countByName(CATAPULT_NAME)).isEqualTo(1);
    }
}
