/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.service;

import static org.fest.assertions.Assertions.assertThat;

import org.apache.lucene.queryParser.ParseException;
import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import almira.sample.dao.Dao;
import almira.sample.domain.Catapult;
import almira.sample.service.CatapultUpdateService;
import almira.sample.testing.CatapultBuilder;

import com.mycila.testing.junit.MycilaJunitRunner;
import com.mycila.testing.plugin.jmock.Mock;
import com.mycila.testing.plugin.jmock.MockContext;


@RunWith(MycilaJunitRunner.class)
public class CatapultUpdateServiceTest {

    private static final Catapult catapult = new CatapultBuilder(1L, "test").build();

    @MockContext private Mockery context;
    @Mock private Dao<Catapult, Long> dao;
    private CatapultUpdateService service;

    @Before
    public void setUp() {
        service = new CatapultUpdateService();
        service.setDao(dao);
    }

    @Test
    public void save() throws ParseException {
        context.checking(new Expectations() {{ oneOf(dao).makePersistent(catapult); will(returnValue(catapult)); }} );
        Catapult c = service.save(catapult);
        assertThat(c).isEqualTo(catapult);
    }

    @Test
    public void delete() throws ParseException {
        context.checking(new Expectations() {{ oneOf(dao).findById(1L, false); will(returnValue(catapult)); }} );
        context.checking(new Expectations() {{ oneOf(dao).makeTransient(catapult); }} );
        service.delete(1L);
    }

    @Test
    public void load() throws InterruptedException {
        context.checking(new Expectations() {{ oneOf(dao).findById(1L, false); will(returnValue(catapult)); }} );
        service.load(1L);
    }
}
