/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web.panel;

import java.util.List;
import java.util.Locale;

import org.apache.wicket.markup.html.form.ChoiceRenderer;
import org.apache.wicket.markup.html.form.DropDownChoice;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.IModel;

/**
 * The Class LocaleDropDownPanel is a custom drop-down panel to select the
 * language for the GUI.
 */
public class LocaleDropDownPanel extends Panel {

    private static final long serialVersionUID = 1L;
    public static final String CHOICE_PATH = "localeChoice";

    /**
     * Add the language panel.
     *
     * @param id
     *            the language id
     * @param supportedLocales
     *            the list of supported locales
     */
    @edu.umd.cs.findbugs.annotations.SuppressWarnings(
          value = {"SE_INNER_CLASS", "SIC_INNER_SHOULD_BE_STATIC_ANON"},
          justification = "This is the Wicket way")

    public LocaleDropDownPanel(String id, List<?> supportedLocales) {
        super(id);

        DropDownChoice<Object> localeDropDown = new DropDownChoice<Object>(CHOICE_PATH, supportedLocales) {
            @Override
            protected boolean wantOnSelectionChangedNotifications() {
                return true;
            }
        };

        localeDropDown.setChoiceRenderer(new ChoiceRenderer<Object>() {
            @Override
            public String getDisplayValue(Object locale) {
                return ((Locale) locale).getDisplayName(getLocale());
            }
        });

        localeDropDown.setModel(new IModel<Object>() {
            @Override
            public Object getObject() {
                return getSession().getLocale();
            }

            @Override
            public void setObject(Object object) {
                getSession().setLocale((Locale) object);
            }

            @Override
            public void detach() {
            }
        });

        add(localeDropDown);
    }
}
