/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import static org.junit.Assert.assertTrue;

import java.util.Locale;

import org.apache.wicket.markup.html.form.DropDownChoice;
import org.apache.wicket.util.tester.WicketTester;
import org.junit.Test;

import almira.sample.web.panel.LocaleDropDownPanel;


/**
 * The Class LocaleDropDownPanelTest.
 */
public class LocaleDropDownPanelTest extends WicketTester {

    /** The Constant PANEL_PATH. */
    private static final String PANEL_PATH = "localeSelectPanel";

    /**
     * Home page renders without errors.
     */
    @Test
    public void homePageRendersWithoutErrors() {
        startPage(PanelContainerPage.class);
        assertRenderedPage(PanelContainerPage.class);
        assertNoErrorMessage();
    }

    /**
     * Home page has local drop down panel.
     */
    @Test
    public void homePageHasLocalDropDownPanel() {
        startPage(PanelContainerPage.class);
        assertComponent(PANEL_PATH, LocaleDropDownPanel.class);

        @SuppressWarnings("unchecked")
        DropDownChoice<Object> ddc = (DropDownChoice<Object>)
                getComponentFromLastRenderedPage(PANEL_PATH + ":"
                        + LocaleDropDownPanel.CHOICE_PATH);

        java.util.List<?> choices = ddc.getChoices();
        assertTrue(choices.contains(Locale.ENGLISH));
    }
}
