/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import java.util.concurrent.atomic.AtomicInteger;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.apache.wicket.Session;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.model.Model;
import org.apache.wicket.protocol.https.RequireHttps;
import org.apache.wicket.spring.injection.annot.SpringBean;

import almira.sample.admin.IndexAdministration;


/**
 * Administration page.
 */
@RequireHttps
public class AdminPage extends AbstractBasePage {

    private static final long serialVersionUID = 1L;
    private static final Logger LOG = Logger.getLogger(AdminPage.class.getName());

    @SpringBean
    private static IndexAdministration indexService;

    public static final String COUNTER_LABEL_ID = "counter";
    public static final String FEEDBACK_LABEL_ID = "feedback";

    /**
     * Constructor.
     */
    @edu.umd.cs.findbugs.annotations.SuppressWarnings(
          value = {"SE_INNER_CLASS", "SIC_INNER_SHOULD_BE_STATIC_ANON"},
          justification = "This is the Wicket way")

    public AdminPage() {
        super();

        final Label counterLabel = new Label(COUNTER_LABEL_ID, "0");
        add(counterLabel);

        final Label feedbackLabel = new Label(FEEDBACK_LABEL_ID);
        add(feedbackLabel);

        add(new Link<String>("increment_counter_link") {
            @Override
            public void onClick() {
                final Session session = AdminPage.this.getSession();
                int counterValue = 0;
                synchronized (session) {
                    AtomicInteger counter = (AtomicInteger) session
                            .getAttribute(COUNTER_LABEL_ID);
                    if (counter == null) {
                        counter = new AtomicInteger();
                    }
                    counterValue = counter.incrementAndGet();
                    // trigger replication to other cluster nodes
                    session.setAttribute(COUNTER_LABEL_ID, counter);
                }
                counterLabel.setDefaultModel(new Model<Integer>(counterValue));
                LOG.fine("*** Catapult counter value=" + counterValue + " ***");
                feedbackLabel.setDefaultModel(new Model<String>());
            }
        });

        add(new Link<String>("rebuild_index") {
            @Override
            public void onClick() {
                try {
                    indexService.rebuildIndex();
                    feedbackLabel.setDefaultModel(new Model<String>(
                            "Rebuilding index."));
                } catch (Exception e) {
                    feedbackLabel.setDefaultModel(new Model<String>(
                            "Error rebuilding index!"));
                    LOG.log(Level.SEVERE, "Error rebuilding", e);
                }
            }
        });
    }
}
