/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import org.apache.wicket.feedback.ContainerFeedbackMessageFilter;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.CompoundPropertyModel;
import org.apache.wicket.request.mapper.parameter.PageParameters;
import org.apache.wicket.spring.injection.annot.SpringBean;
import org.apache.wicket.validation.validator.StringValidator;

import almira.sample.domain.Catapult;
import almira.sample.service.ObjectUpdateService;


/**
 * Index page.
 */
public class IndexPage extends AbstractBasePage {

    private static final long serialVersionUID = 1L;
    private static final int MAXIMUM_FIELD_LENGTH = 20;

    @SpringBean
    private static ObjectUpdateService<Catapult, Long> catapultUpdateService;

    private static final Form<Catapult> CATAPULT_CREATION_FORM = new Form<Catapult>("form") {

        @Override
        protected void onSubmit() {
            Catapult catapult = getModelObject();
            catapultUpdateService.save(catapult);

            PageParameters params = new PageParameters();
            params.add("catapultId", catapult.getId());
            setResponsePage(ShowCatapultPage.class, params);
        }
    };

    // We need to do this only once, and only when the object has been created.
    // See: http://download.oracle.com/javase/tutorial/java/javaOO/initial.html
    static {
        CATAPULT_CREATION_FORM.add(new TextField<String>("name")
                .setRequired(true)
                .add(StringValidator.maximumLength(MAXIMUM_FIELD_LENGTH)));

    }

    /**
     * Constructor.
     */
    public IndexPage() {
        super();

        final Catapult catapult = new Catapult();
        final CompoundPropertyModel<Catapult> model = new CompoundPropertyModel<Catapult>(catapult);
        CATAPULT_CREATION_FORM.setModel(model);
        add(CATAPULT_CREATION_FORM);

        // add feedback panel to display any feedback messages for this form
        add(new FeedbackPanel("feedback", new ContainerFeedbackMessageFilter(
                CATAPULT_CREATION_FORM)));
    }
}
