/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import java.util.logging.Logger;

import org.junit.BeforeClass;
import org.junit.Test;

import almira.sample.admin.IndexAdministration;
import almira.sample.web.AdminPage;


public class WicketAdminPageTest extends AbstractWicketSpringPageTest {

    private static final Logger LOG = Logger
            .getLogger(WicketAdminPageTest.class.getName());

    @BeforeClass
    public static void setUpContext() {
        putBeanOnce("catapultIndexService", new IndexAdministration() {
            @Override
            public void rebuildIndex() throws InterruptedException {
                LOG.fine("Rebuilding index.");
            }
        });
    }

    @Test
    public void adminPageRendersWithoutErrors() {
        startPage(AdminPage.class);
        assertRenderedPage(AdminPage.class);
        assertNoErrorMessage();
    }

    @Test
    public void counterIncrementsByOneWhenClicked() {
        startPage(AdminPage.class);
        assertLabel(AdminPage.COUNTER_LABEL_ID, "0");
        clickLink("increment_counter_link");
        assertLabel(AdminPage.COUNTER_LABEL_ID, "1");
    }

    @Test
    public void triggersIndexRebuildWhenClicked() {
        startPage(AdminPage.class);
        assertLabel(AdminPage.FEEDBACK_LABEL_ID, "");
        clickLink("rebuild_index");
        assertLabel("feedback", "Rebuilding index.");
    }
}
