/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import java.util.List;

import org.apache.lucene.queryParser.ParseException;
import org.apache.wicket.request.mapper.parameter.PageParameters;
import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import almira.sample.domain.Catapult;
import almira.sample.service.ObjectQueryService;
import almira.sample.service.ObjectUpdateService;
import almira.sample.testing.CatapultBuilder;
import almira.sample.web.ListCatapultsPage;

import com.mycila.testing.junit.MycilaJunitRunner;
import com.mycila.testing.plugin.jmock.Mock;
import com.mycila.testing.plugin.jmock.MockContext;


@RunWith(MycilaJunitRunner.class)
public class WicketListCatapultsPageTest extends AbstractWicketSpringPageTest {

    @MockContext
    private Mockery context;

    @Mock private static ObjectQueryService<Catapult, Long> queryService;
    @Mock private static ObjectUpdateService<Catapult, Long> updateService;

    private static final String CATAPULT_NAME = "catapultName";
    private static Catapult catapult = new CatapultBuilder(1L, CATAPULT_NAME).build();
    private static List<Catapult> resultList = new CatapultBuilder(1L, CATAPULT_NAME).asList();

    @Before
    public void setUp() {
        putBeanOnce("catapultQueryService", queryService);
        putBeanOnce("catapultUpdateService", updateService);
    }

    @edu.umd.cs.findbugs.annotations.SuppressWarnings(
      value = {"SIC_INNER_SHOULD_BE_STATIC_ANON"}, justification = "This is the jMock way")

    @Test
    public void pageRendersWithoutErrors() throws ParseException {
        context.checking(new Expectations() {{
            atLeast(1).of(queryService).searchByName(CATAPULT_NAME, 0, 1);
            will(returnValue(resultList));

            atLeast(1).of(queryService).countByName(CATAPULT_NAME);
            will(returnValue(1));

            atLeast(1).of(queryService).load(1L);
            will(returnValue(catapult));
        }});

        PageParameters params = new PageParameters();
        params.add("searchString", CATAPULT_NAME);
        startPage(ListCatapultsPage.class, params);
        assertRenderedPage(ListCatapultsPage.class);
        assertNoErrorMessage();
    }
}
