/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package almira.sample.web;

import org.apache.wicket.request.mapper.parameter.PageParameters;
import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import almira.sample.domain.Catapult;
import almira.sample.service.ObjectLoadService;
import almira.sample.testing.CatapultBuilder;
import almira.sample.web.ShowCatapultPage;

import com.mycila.testing.junit.MycilaJunitRunner;
import com.mycila.testing.plugin.jmock.Mock;
import com.mycila.testing.plugin.jmock.MockContext;


@RunWith(MycilaJunitRunner.class)
public class WicketShowCatapultPageTest extends AbstractWicketSpringPageTest {

    @MockContext
    private Mockery context;

    private static final String CATAPULT_NAME = "catapultName";
    private static Catapult catapult = new CatapultBuilder(1L, CATAPULT_NAME).build();

    @Mock private ObjectLoadService<Catapult, Long> loadService;

    @Before
    public void setUp() {
        putBeanOnce("catapultLoadService", loadService);
    }

    @edu.umd.cs.findbugs.annotations.SuppressWarnings(
      value = {"SIC_INNER_SHOULD_BE_STATIC_ANON"}, justification = "This is the jMock way")

    @Test
    public void catapultNameIsDiplayed() {
        context.checking(new Expectations() {{
            atLeast(1).of(loadService).load(1L);
            will(returnValue(catapult));
        }});
        PageParameters params = new PageParameters();
        params.add("catapultId", "1");
        startPage(ShowCatapultPage.class, params);
        assertRenderedPage(ShowCatapultPage.class);
        assertNoErrorMessage();
        assertLabel("name", CATAPULT_NAME);
    }
}
